==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/postfinanceag_basic.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	postfinanceag_basic.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. CH,AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_CURRENCY_DESC' => 'Währung, welche für Kreditkartentransaktionen verwendet wird',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_CURRENCY_TITLE' => 'Währung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ERROR' => 'Die Zahlung wurde von der Postfinance abgelehnt!',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ERROR_ORDER_STATUS_ID_DESC' => 'Abgebrochene oder abgelehnte Bestellungen auf diesen Status setzen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ERROR_ORDER_STATUS_ID_TITLE' => 'Bestellstatus bei Abbruch festlegen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_LANGUAGE_DESC' => 'Sprache in der die Postfinance Benutzeroberfläche angezeigt wird',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_LANGUAGE_TITLE' => 'Benutzermaskensprache',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PRODUCTIVE_DESC' => 'Wählen Sie True, wenn Ihr Shop Produktiv ist ansonsten False',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PRODUCTIVE_TITLE' => 'TEST- oder PRODUKTIV Modus?',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_PRODUCTIVE_DESC' => 'Ihr Benutzername für die Produktivumgebung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_PRODUCTIVE_TITLE' => 'PSPID PRODUKTIV',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_TEST_DESC' => 'Ihr Benutzername für die Testumgebung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_TEST_TITLE' => 'PSPID TEST',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SHA_SIGNATURE_DESC' => 'Ihre SHA-512 Signature für die Datenüberprüfung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SHA_SIGNATURE_TITLE' => 'SHA-512 Signature',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_STATUS_DESC' => 'Möchten Sie Zahlungen per Postfinance akzeptieren?',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_STATUS_TITLE' => 'Postfinance Modul aktivieren',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_DESCRIPTION' => 'Postfinance Basic (Postcard, E-Finance)<br />Information: <a href="http://www.postfinance.ch/pf/content/de/seg/biz/product/eserv/epay/seller/offer.html" target="_blank">www.postfinance.ch</a><br />Support: <a href="http://www.swisswebxperts.ch/postfinance.php" target="_blank">www.swisswebXperts.ch</a>',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_ERROR' => 'Postfinance Basic - Transaktionsfehler',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_INFO' => '',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_TITLE' => 'Onlinezahlung Postcard / e-Finance',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_UTF8_DESC' => 'Standard UTF8 (ab Version GX2.1) <br />Diese Einstellung muss mit der im Postfinance Backend übereinstimmen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_UTF8_TITLE' => 'Charset',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ZONE_TITLE' => 'Zahlungszone'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/postfinanceag_basic.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	postfinanceag_basic.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. CH,AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_CURRENCY_DESC' => 'Währung, welche für Kreditkartentransaktionen verwendet wird',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_CURRENCY_TITLE' => 'Währung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ERROR' => 'Die Zahlung wurde von der Postfinance abgelehnt!',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ERROR_ORDER_STATUS_ID_DESC' => 'Abgebrochene oder abgelehnte Bestellungen auf diesen Status setzen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ERROR_ORDER_STATUS_ID_TITLE' => 'Bestellstatus bei Abbruch festlegen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_LANGUAGE_DESC' => 'Sprache in der die Postfinance Benutzeroberfläche angezeigt wird',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_LANGUAGE_TITLE' => 'Benutzermaskensprache',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PRODUCTIVE_DESC' => 'Wähle True, wenn dein Shop produktiv ist, ansonsten False',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PRODUCTIVE_TITLE' => 'TEST- oder PRODUKTIV Modus?',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_PRODUCTIVE_DESC' => 'Dein Benutzername für die Produktivumgebung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_PRODUCTIVE_TITLE' => 'PSPID PRODUKTIV',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_TEST_DESC' => 'Dein Benutzername für die Testumgebung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_PSPID_TEST_TITLE' => 'PSPID TEST',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SHA_SIGNATURE_DESC' => 'Deine SHA-512 Signature für die Datenüberprüfung',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SHA_SIGNATURE_TITLE' => 'SHA-512 Signature',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_STATUS_DESC' => 'Möchtest du Zahlungen per Postfinance akzeptieren?',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_STATUS_TITLE' => 'Postfinance Modul aktivieren',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_DESCRIPTION' => 'Postfinance Basic (Postcard, E-Finance)<br />Information: <a href="http://www.postfinance.ch/pf/content/de/seg/biz/product/eserv/epay/seller/offer.html" target="_blank">www.postfinance.ch</a><br />Support: <a href="http://www.swisswebxperts.ch/postfinance.php" target="_blank">www.swisswebXperts.ch</a>',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_ERROR' => 'Postfinance Basic - Transaktionsfehler',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_INFO' => '',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_TEXT_TITLE' => 'Onlinezahlung Postcard / e-Finance',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_UTF8_DESC' => 'Standard UTF8 (ab Version GX2.1) <br />Diese Einstellung muss mit der im Postfinance Backend übereinstimmen',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_UTF8_TITLE' => 'Charset',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_POSTFINANCEAG_BASIC_ZONE_TITLE' => 'Zahlungszone'
);
